# -*- coding:utf-8 -*-
# @Author cc
# @TIME 2020/5/25 16:02
import re

import requests

from translate_util.base_translate import BaseTranslate


class GoogleTranslate(BaseTranslate):

    def trans_text_other2cn(self):
        return self.trans_text(self.content, tl='zh-CN')

    def trans_text_other2en(self):
        return self.trans_text(self.content, tl='en')

    def trans_text(self, st: [str, bytes], sl='auto', tl='zh-CN') -> str:
        """
        将字符串翻译成指定国家语言
        :param st: 待翻译的字符串
        :param sl: 待翻译的语言 默认auto
        :param tl: 翻译成的语言
        :return: 翻译后的字符串
        """
        url = "https://www.google.com.hk/async/translate"

        payload = f"async=translate,sl:{sl},tl:{tl},st:{st.encode('utf-8')},id:1672056488960,qc:true,ac:true,_id:tw-async-translate,_pms:s,_fmt:pc"
        headers = {
            'sec-ch-ua': '"Not?A_Brand";v="8", "Chromium";v="108", "Google Chrome";v="108"',
            'DNT': '1',
            'sec-ch-ua-mobile': '?0',
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/108.0.0.0 Safari/537.36',
            'sec-ch-ua-arch': '"x86"',
            'sec-ch-ua-full-version': '"108.0.5359.125"',
            'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8',
            'sec-ch-ua-platform-version': '"10.0.0"',
            'sec-ch-ua-full-version-list': '"Not?A_Brand";v="8.0.0.0", "Chromium";v="108.0.5359.125", "Google Chrome";v="108.0.5359.125"',
            'sec-ch-ua-bitness': '"64"',
            'sec-ch-ua-model': '',
            'sec-ch-ua-wow64': '?0',
            'sec-ch-ua-platform': '"Windows"',
            'Accept': '*/*',
            'X-Client-Data': 'CKW1yQEIhbbJAQiktskBCMS2yQEIqZ3KAQjb08oBCLD+ygEIlaHLAQjv8swBCN75zAEI5PrMAQjxgM0BCLKCzQEI7ILNAQjIhM0BCO+EzQEIt4XNAQ==',
            'Sec-Fetch-Site': 'same-origin',
            'Sec-Fetch-Mode': 'cors',
            'Sec-Fetch-Dest': 'empty',
            'host': 'www.google.com.hk',
            'Cookie': '1P_JAR=2022-12-26-12; NID=511=eVLI1bG9nhyOZtqU14JBHm5Be00epdxfR4XmfQeehYyIkzgpXi6dbpNY75ZMVyS7aOjoM2oZ5WdoR8eNq6wi1-e_J0NeoyI0dtsHW-_8Ik4PGrqvuGHdcvVC03zTOEK2TY1FZL85Wimo_ZPIE3hGIrmGPSiel6-rRRW9lD30UPs'
        }

        response = requests.request("POST", url, headers=headers, data=payload)
        res_text = response.content.decode()
        print(res_text)
        res_array = re.findall(r'id="tw-answ-target-text">(.*?)</span>', res_text,
                               flags=re.IGNORECASE)
        return res_array[0]


if __name__ == '__main__':
    for source_text in ['china', 'je suis un']:
        _rs = GoogleTranslate(content=source_text).trans_text_other2cn()
        print(_rs)
    for source_text in ['31 maggio 2021', '中国']:
        res = GoogleTranslate(content=source_text).trans_text_other2en()
        print(res)



# -*- coding:utf-8 -*-
# @Author cc
# @TIME 2020/5/25 16:46
import traceback

from retrying import retry
from translate_util.translate_google import GoogleTranslate


@retry(stop_max_attempt_number=3)
def translate_en2cn(content: str, platform: str = 'google', proxies: str = None):
    """
    根据翻译平台将中文翻译成英文
    :param content: 带翻译的平台
    :param platform: 使用的翻译平台 google,baidu,iciba,youdao
    :param proxies: 代理IP(5.34.178.48:8080)
    :return: 翻译后的内容 string
    """
    try:
        if platform == 'google':
            return GoogleTranslate(content=content, proxies=proxies).trans_text_en2cn()
        # elif platform == 'baidu':
        #     return BaiduTranslate(content=content, proxies=proxies).trans_text_en2cn()
        # elif platform == 'iciba':
        #     return BaiduTranslate(content=content, proxies=proxies).trans_text_en2cn()
        # elif platform == 'youdao':
        #    return YoudaoTranslate(content=content, proxies=proxies).trans_text_en2cn()
        else:
            return GoogleTranslate(content=content, proxies=proxies).trans_text_en2cn()
    except(Exception,):
        raise Exception(traceback.format_exc())

@retry(stop_max_attempt_number=3)
def translate_text(content: str, sl='auto', tl='zh-CN'):
    try:
        return GoogleTranslate(content=content).trans_text(content, sl, tl)
    except(Exception,):
        raise Exception(traceback.format_exc())


@retry(stop_max_attempt_number=3)
def translate_other2cn(content: str, platform='google', proxies: str = None):
    """
    根据翻译平台将其它语言翻译成中文
    :param content: 带翻译的平台
    :param platform: 使用的翻译平台 google,baidu,iciba,youdao
    :param proxies: 代理IP(5.34.178.48:8080)
    :return: 翻译后的内容 string
    """
    try:
        if platform == 'google':
            return GoogleTranslate(content=content, proxies=proxies).trans_text_other2cn()
        # elif platform == 'baidu':
        #     return BaiduTranslate(content=content, proxies=proxies).trans_text_other2cn()
        # elif platform == 'iciba':
        #     return BaiduTranslate(content=content, proxies=proxies).trans_text_other2cn()
        # elif platform == 'youdao':
        #     return YoudaoTranslate(content=content, proxies=proxies).trans_text_other2cn()
        else:
            return GoogleTranslate(content=content).trans_text_other2cn()
    except(Exception,):
        raise Exception(traceback.format_exc())


@retry(stop_max_attempt_number=3)
def translate_other2en(content: str, platform='google', proxies: str = None, sl: str = 'auto'):
    """
    根据翻译平台将其它语言翻译成英文
    :param content: 带翻译的平台
    :param platform: 使用的翻译平台 google,baidu,iciba,youdao
    :param proxies: 代理IP(5.34.178.48:8080)
    :param sl: 源语言的编码
    :return: 翻译后的内容 string
    """
    try:
        if platform == 'google':
            return GoogleTranslate(content=content, proxies=proxies, sl=sl).trans_text_other2en()
        # elif platform == 'baidu':
        #     return BaiduTranslate(content=content, proxies=proxies, sl=sl).trans_text_other2en()
        # elif platform == 'iciba':
        #     return BaiduTranslate(content=content, proxies=proxies, sl=sl).trans_text_other2en()
        # elif platform == 'youdao':
        #     return YoudaoTranslate(content=content, proxies=proxies, sl=sl).trans_text_other2en()
        # else:
        #     return GoogleTranslate(content=content, proxies=proxies).trans_text_other2en()
    except(Exception,):
        raise Exception(traceback.format_exc())


if __name__ == '__main__':
    # _content = 'china'
    # for plat in ['google', 'baidu', 'iciba', 'youdao']:
    #     print(f'{plat}:{translate_other2cn(_content, plat)}')

    _content = '31 maggio 2021'
    for plat in ['google']:
        print(f'{plat}:{translate_other2en(_content, plat, sl="it")}')

    tran_rs = translate_other2cn(content='chinese', platform='google', proxies='5.34.178.48:8080')
    print(tran_rs)

    res = translate_text('我是中国人', tl='fr')
    print(res)



# -*- coding: utf-8 -*-
# @Time    : 2020/6/12 23:04
# @Author  : CC
# @Desc    : common_request.py
import requests
from retrying import retry


def send_request(method, url, headers=None, params=None, data=None, proxies=None, timeout=10, max_attempt_number=3):
    if isinstance(proxies, str):
        proxies = {"https": proxies, "http": proxies}

    @retry(stop_max_attempt_number=max_attempt_number)
    def _send_request():
        response = requests.request(method, url, headers=headers, params=params, data=data, proxies=proxies,
                                    timeout=timeout)
        return response

    return _send_request()


if __name__ == '__main__':
    res = send_request("get", "https://www.baidu.com/")
    print(res.status_code)



# -*- coding:utf-8 -*-
# @Author cc
# @TIME 2020/5/25 15:46

from translate_util.base_translate import BaseTranslate
from translate_util.common_request import send_request


class YoudaoTranslate(BaseTranslate):

    def trans_text_en2cn(self):
        """
        type 枚举值
        ZH_CN2EN 中文　»　英语
        ZH_CN2JA 中文　»　日语
        ZH_CN2KR 中文　»　韩语
        ZH_CN2FR 中文　»　法语
        ZH_CN2RU 中文　»　俄语
        ZH_CN2SP 中文　»　西语
        EN2ZH_CN 英语　»　中文
        JA2ZH_CN 日语　»　中文
        KR2ZH_CN 韩语　»　中文
        FR2ZH_CN 法语　»　中文
        RU2ZH_CN 俄语　»　中文
        SP2ZH_CN 西语　»　中文
        :return: 
        """
        url = f'http://fanyi.youdao.com/translate?&doctype=json&from={self.sl.upper()}&to=zh-CHS&i={self.content}'
        r = send_request('get', url, proxies=self.proxies)
        rs = []
        for result in r.json()['translateResult'][0]:
            rs.append(result['tgt'])
        return ''.join(rs)

    def trans_text_other2cn(self):
        return self.trans_text_en2cn()

    def trans_text_other2en(self):
        url = f'http://fanyi.youdao.com/translate?&doctype=json&from={self.sl.upper()}&to=en&i={self.content}'
        r = send_request('get', url, )
        rs = []
        for result in r.json()['translateResult'][0]:
            rs.append(result['tgt'])
        return ''.join(rs)


if __name__ == '__main__':
    for source_text in ['china', '저는 중국사람입니다']:
        _rs = YoudaoTranslate(content=source_text).trans_text_other2cn()
        print(_rs)

    for source_text in ['31 maggio 2021']:
        res = YoudaoTranslate(content=source_text, sl='it').trans_text_other2en()
        print(res)



# -*- coding:utf-8 -*-
# @Author cc
# @TIME 2020/5/25 16:25
import abc
from loguru import logger


class BaseTranslate(metaclass=abc.ABCMeta):
    def __init__(self, content: str, proxies: str = None, sl='auto'):
        """
        :param content: 待翻译的内容
        :param proxies: 代理IP(5.34.178.48:8080)
        :param sl: 待翻译内容的语言编码(en)
        """
        self.content = content
        self.proxies = proxies
        self.logger = logger
        self.sl = sl

    def trans_text_en2cn(self):
        pass

    def trans_text_other2cn(self):
        pass

    def trans_text_other2en(self):
        pass

    def trans_text(self, st: str, sl='auto', tl='zh-CN'):
        pass



# -*- coding:utf-8 -*-
# @Author cc
# @TIME 2020/5/25 15:29

from requests import Session

from translate_util.base_translate import BaseTranslate


class IcibaTranslate(BaseTranslate):
    s = Session()
    url = 'http://fy.iciba.com/ajax.php'

    def trans_text_en2cn(self):
        params = {
            'a': 'fy',
            'f': self.sl,
            't': 'zh-CN',
            'w': self.content
        }
        r = self.s.request('get', self.url, params=params, )
        # self.logger.info(r.text)
        rs = r.json()['content'].get('out') if r.json()['content'].get('out') else r.json()['content'].get('word_mean')
        return rs[0].replace('n. ', '').replace(';', '') if isinstance(rs, list) else rs

    def trans_text_other2cn(self):
        return self.trans_text_en2cn()

    def trans_text_other2en(self):
        params = {
            'a': 'fy',
            'f': self.sl,
            't': 'en',
            'w': self.content
        }
        r = self.s.request('get', self.url, params=params, )
        # self.logger.info(r.text)
        rs = r.json()['content'].get('out') if r.json()['content'].get('out') else r.json()['content'].get('word_mean')
        return rs[0].replace('n. ', '').replace(';', '') if isinstance(rs, list) else rs


if __name__ == '__main__':
    for source_text in ['china', '저는 중국사람입니다']:
        _rs = IcibaTranslate(content=source_text).trans_text_other2cn()
        print(_rs)
    for source_text in ['中国', '저는 중국사람입니다']:
        res = IcibaTranslate(content=source_text).trans_text_other2en()
        print(res)



# -*- coding:utf-8 -*-
# @Author cc
# @TIME 2020/04/29 23:26
# coding=utf-8

from setuptools import setup, find_packages

setup(
    name='translate_util',
    version='1.1.1',
    description=(
        'translate tool support(google)'
    ),
    long_description_content_type="text/markdown",
    long_description=open('README.md').read(),
    author='cc',
    author_email='abcdef123456chen@sohu.com',
    maintainer='cc',
    maintainer_email='abcdef123456chen@sohu.com',
    license='MIT License',
    install_requires=[
        "requests>=2.22.0",
        "retrying>=1.3.3",
        "loguru>=0.3.2",
        "PyExecJS>=1.5.1"
    ],
    packages=find_packages(),
    platforms=["all"],
    url='https://github.com/abo123456789/translate_util',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: Implementation',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries'
    ])